==> nextcloud-app-calendar-1%3A6.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Вітаем,",
    "Upcoming events" : "Будучыя падзеі",
    "No upcoming events" : "Няма будучых падзей",
    "%1$s with %2$s" : "%1$s з %2$s",
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Вы атрымаеце спасылку з пацвярджэннем па электроннай пошце",
    "Where:" : "Дзе:",
    "Comment:" : "Каментарый:",
    "Location:" : "Месцазнаходжанне:",
    "%1$s minutes" : "%1$s хв",
    "Duration:" : "Працягласць:",
    "%1$s from %2$s to %3$s" : "%1$s з %2$s да %3$s",
    "Dates:" : "Даты:",
    "Respond" : "Адказаць",
    "A Calendar app for Nextcloud" : "Праграма Каляндар для Nextcloud",
    "Next week" : "На наступным тыдні",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "List" : "Спіс",
    "Appointment link was copied to clipboard" : "Спасылка на сустрэчу скапіявана ў буфер абмену",
    "Appointment link could not be copied to clipboard" : "Не ўдалося скапіяваць спасылку на сустрэчу ў буфер абмену",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Appointment schedules" : "Расклад сустрэч",
    "Create new" : "Стварыць новую",
    "Disable calendar \"{calendar}\"" : "Адключыць каляндар \"{calendar}\"",
    "Disable untitled calendar" : "Адключыць каляндар без назвы",
    "Enable calendar \"{calendar}\"" : "Уключыць каляндар \"{calendar}\"",
    "Enable untitled calendar" : "Уключыць каляндар без назвы",
    "Untitled calendar" : "Каляндар без назвы",
    "Edit calendar" : "Рэдагаваць каляндар",
    "Calendars" : "Календары",
    "New calendar with task list" : "Новы каляндар са спісам заданняў",
    "Export" : "Экспарт",
    "Trash bin" : "Сметніца",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Shared calendars" : "Абагуленыя календары",
    "Internal link" : "Унутраная спасылка",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "Save" : "Захаваць",
    "View" : "Праглядзець",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Attachments folder" : "Папка для далучэнняў",
    "Timezone" : "Часавы пояс",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "or" : "або",
    "General" : "Агульныя",
    "Availability settings" : "Налады даступнасці",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Доступ да календароў Nextcloud з іншых праграм і прылад",
    "CalDAV URL" : "URL-адрас CalDAV",
    "Appearance" : "Знешні выгляд",
    "Birthday calendar" : "Каляндар дзён нараджэння",
    "Tasks in calendar" : "Заданні ў календары",
    "Weekends" : "Уік-энды",
    "Week numbers" : "Нумары тыдняў",
    "Files" : "Файлы",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Visibility" : "Бачнасць",
    "Duration" : "Працягласць",
    "to" : "на",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Successfully added Talk conversation link to description." : "Спасылка на размову ў Talk паспяхова дададзена ў апісанне.",
    "Select conversation" : "Выберыце размову",
    "on" : "укл.",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Proceed" : "Працягнуць",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "Confirmation" : "Пацвярджэнне",
    "_{count} attachment_::_{count} attachments_" : ["{count} далучэнне","{count} далучэнні","{count} далучэнняў","{count} далучэнняў"],
    "Accepted {organizerName}'s invitation" : "Прынята запрашэнне {organizerName}",
    "Declined {organizerName}'s invitation" : "Адхілена запрашэнне {organizerName}",
    "{organizer} (organizer)" : "{organizer} (арганізатар)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Out of office" : "Па-за офісам",
    "Attendees:" : "Удзельнікі:",
    "local time" : "мясцовы час",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "No attendees yet" : "Пакуль няма ўдзельнікаў",
    "Attendees" : "Удзельнікі",
    "Remove group" : "Выдаліць групу",
    "Remove attendee" : "Выдаліць удзельніка",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "(organizer)" : "(арганізатар)",
    "From" : "З",
    "To" : "Да",
    "Your Time" : "Ваш час",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Attendance required" : "Наведванне абавязковае",
    "Attendance optional" : "Наведванне неабавязковае",
    "Remove participant" : "Выдаліць удзельніка",
    "Yes" : "Так",
    "No" : "Не",
    "Maybe" : "Магчыма",
    "None" : "Няма",
    "Create" : "Ствараць",
    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Select a date" : "Выберыце дату",
    "Time:" : "Час:",
    "Personal" : "Асабістыя",
    "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
    "Unscheduled tasks" : "Незапланаваныя заданні",
    "Availability of {displayName}" : "Даступнасць {displayName}",
    "All day" : "Увесь дзень",
    "Invite" : "Запрасіць",
    "Discard changes?" : "Адхіліць змены?",
    "Untitled event" : "Падзея без назвы",
    "Close" : "Закрыць",
    "Selected" : "Выбрана",
    "No Description" : "Няма апісання",
    "Title" : "Загаловак",
    "15 min" : "15 хв",
    "30 min" : "30 хв",
    "60 min" : "60 хв",
    "90 min" : "90 хв",
    "Participants" : "Удзельнікі",
    "Submit" : "Адправіць",
    "Meeting" : "Сустрэча",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Заданне без назвы",
    "Please ask your administrator to enable the Tasks App." : "Папрасіце адміністратара ўключыць праграму Заданні.",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Other" : "Іншае",
    "Add a location" : "Дадайце месцазнаходжанне",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Дадайце апісанне\n\n- Пра што гэтая сустрэча\n- Пункты парадку дня\n- Што трэба падрыхтаваць удзельнікам",
    "Status" : "Статус",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "Error while sharing file" : "Памылка пры абагульванні файла",
    "User not found" : "Карыстальнік не знойдзены",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendar name …" : "Назва календара …",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Show tasks in calendar" : "Паказаць заданні ў календары",
    "Show weekends" : "Паказваць уік-энды",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-calendar-1%3A6.1.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Вітаем,",
    "Upcoming events" : "Будучыя падзеі",
    "No upcoming events" : "Няма будучых падзей",
    "%1$s with %2$s" : "%1$s з %2$s",
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Вы атрымаеце спасылку з пацвярджэннем па электроннай пошце",
    "Where:" : "Дзе:",
    "Comment:" : "Каментарый:",
    "Location:" : "Месцазнаходжанне:",
    "%1$s minutes" : "%1$s хв",
    "Duration:" : "Працягласць:",
    "%1$s from %2$s to %3$s" : "%1$s з %2$s да %3$s",
    "Dates:" : "Даты:",
    "Respond" : "Адказаць",
    "A Calendar app for Nextcloud" : "Праграма Каляндар для Nextcloud",
    "Next week" : "На наступным тыдні",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "List" : "Спіс",
    "Appointment link was copied to clipboard" : "Спасылка на сустрэчу скапіявана ў буфер абмену",
    "Appointment link could not be copied to clipboard" : "Не ўдалося скапіяваць спасылку на сустрэчу ў буфер абмену",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Appointment schedules" : "Расклад сустрэч",
    "Create new" : "Стварыць новую",
    "Disable calendar \"{calendar}\"" : "Адключыць каляндар \"{calendar}\"",
    "Disable untitled calendar" : "Адключыць каляндар без назвы",
    "Enable calendar \"{calendar}\"" : "Уключыць каляндар \"{calendar}\"",
    "Enable untitled calendar" : "Уключыць каляндар без назвы",
    "Untitled calendar" : "Каляндар без назвы",
    "Edit calendar" : "Рэдагаваць каляндар",
    "Calendars" : "Календары",
    "New calendar with task list" : "Новы каляндар са спісам заданняў",
    "Export" : "Экспарт",
    "Trash bin" : "Сметніца",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Shared calendars" : "Абагуленыя календары",
    "Internal link" : "Унутраная спасылка",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "Save" : "Захаваць",
    "View" : "Праглядзець",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Attachments folder" : "Папка для далучэнняў",
    "Timezone" : "Часавы пояс",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "or" : "або",
    "General" : "Агульныя",
    "Availability settings" : "Налады даступнасці",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Доступ да календароў Nextcloud з іншых праграм і прылад",
    "CalDAV URL" : "URL-адрас CalDAV",
    "Appearance" : "Знешні выгляд",
    "Birthday calendar" : "Каляндар дзён нараджэння",
    "Tasks in calendar" : "Заданні ў календары",
    "Weekends" : "Уік-энды",
    "Week numbers" : "Нумары тыдняў",
    "Files" : "Файлы",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "(copy)" : "(копія)",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Visibility" : "Бачнасць",
    "Duration" : "Працягласць",
    "to" : "на",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Successfully added Talk conversation link to description." : "Спасылка на размову ў Talk паспяхова дададзена ў апісанне.",
    "Select conversation" : "Выберыце размову",
    "on" : "укл.",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Proceed" : "Працягнуць",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "Confirmation" : "Пацвярджэнне",
    "_{count} attachment_::_{count} attachments_" : ["{count} далучэнне","{count} далучэнні","{count} далучэнняў","{count} далучэнняў"],
    "Accepted {organizerName}'s invitation" : "Прынята запрашэнне {organizerName}",
    "Declined {organizerName}'s invitation" : "Адхілена запрашэнне {organizerName}",
    "{organizer} (organizer)" : "{organizer} (арганізатар)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Out of office" : "Па-за офісам",
    "Attendees:" : "Удзельнікі:",
    "local time" : "мясцовы час",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Copied to clipboard" : "Скапіявана ў буфер абмену",
    "No attendees yet" : "Пакуль няма ўдзельнікаў",
    "Attendees" : "Удзельнікі",
    "Remove group" : "Выдаліць групу",
    "Remove attendee" : "Выдаліць удзельніка",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "(organizer)" : "(арганізатар)",
    "From" : "З",
    "To" : "Да",
    "Your Time" : "Ваш час",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Attendance required" : "Наведванне абавязковае",
    "Attendance optional" : "Наведванне неабавязковае",
    "Remove participant" : "Выдаліць удзельніка",
    "Yes" : "Так",
    "No" : "Не",
    "Maybe" : "Магчыма",
    "None" : "Няма",
    "Create" : "Ствараць",
    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Select a date" : "Выберыце дату",
    "Time:" : "Час:",
    "Personal" : "Асабістыя",
    "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
    "Unscheduled tasks" : "Незапланаваныя заданні",
    "Availability of {displayName}" : "Даступнасць {displayName}",
    "Discard changes" : "Адхіліць змены",
    "All day" : "Увесь дзень",
    "Invite" : "Запрасіць",
    "Discard changes?" : "Адхіліць змены?",
    "Untitled event" : "Падзея без назвы",
    "Close" : "Закрыць",
    "Selected" : "Выбрана",
    "No Description" : "Няма апісання",
    "Title" : "Загаловак",
    "15 min" : "15 хв",
    "30 min" : "30 хв",
    "60 min" : "60 хв",
    "90 min" : "90 хв",
    "Participants" : "Удзельнікі",
    "Submit" : "Адправіць",
    "Meeting" : "Сустрэча",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Заданне без назвы",
    "Please ask your administrator to enable the Tasks App." : "Папрасіце адміністратара ўключыць праграму Заданні.",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Other" : "Іншае",
    "Add a location" : "Дадайце месцазнаходжанне",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Дадайце апісанне\n\n- Пра што гэтая сустрэча\n- Пункты парадку дня\n- Што трэба падрыхтаваць удзельнікам",
    "Status" : "Статус",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "Error while sharing file" : "Памылка пры абагульванні файла",
    "User not found" : "Карыстальнік не знойдзены",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Calendar name …" : "Назва календара …",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Show tasks in calendar" : "Паказаць заданні ў календары",
    "Show weekends" : "Паказваць уік-энды",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
